/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.eventmesh.connector.jdbc;

import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

import lombok.Data;

@Data
public class Schema {

    // contains primary key and unique key
    private Set<String> keySet;

    private List<Field> fields;

    public Schema(List<Field> fields) {
        this.fields = fields;
    }

    public Schema() {
        this.fields = new ArrayList<>();
    }

    public void add(Field field) {
        this.fields.add(field);
    }

    public void addKey(String key) {
        if (keySet == null) {
            keySet = new HashSet<>();
        }
        this.keySet.add(key);
    }

    public void addKeys(Collection<String> keys) {
        if (keySet == null) {
            keySet = new HashSet<>();
        }
        this.keySet.addAll(keys);
    }

    public boolean containsKey() {
        return keySet != null && !keySet.isEmpty();
    }
}
